==> dspygen-2024.4.30.tar.gz: dspygen-2024.4.30/src/dspygen/experiments/done/wizard.py <==
import typer
from typing import Optional
from pydantic import BaseModel, ValidationError
import yaml
import os
import json

from dspygen.dsl.dsl_pydantic_models import PipelineConfigModel

app = typer.Typer()


def load_user_history() -> dict:
    """
    Simulate loading user's history to predict configurations.
    """
    # Placeholder for loading and analyzing user's history
    return {}


def generate_optimized_configuration(user_history: dict) -> PipelineConfigModel:
    """
    Generate an optimized pipeline configuration based on the user's history.
    """
    # Placeholder for AI logic to generate optimized configs
    return PipelineConfigModel()


def save_configuration(config: PipelineConfigModel, filename: str):
    """
    Save the generated pipeline configuration to a YAML file.
    """
    with open(filename, 'w') as file:
        yaml.dump(json.loads(config.json()), file)


@app.command()
def create_pipeline(filename: Optional[str] = typer.Option(None, "--filename", "-f",
                                                           help="Filename to save the pipeline configuration.")):
    """
    Main command to initiate the pipeline configuration generation process.
    """
    user_history = load_user_history()
    optimized_config = generate_optimized_configuration(user_history)

    # Proactively offer the optimized configuration with an option for details or modifications
    typer.echo("Based on your history, an optimized pipeline configuration has been generated.")
    action = typer.prompt("Do you want to proceed with the optimized configuration? (Y/n/details)", default="Y")

    if action.lower() == 'n':
        typer.echo("Exiting... You can start over and customize your configuration.")
        raise typer.Exit()
    elif action.lower() == 'details':
        typer.echo(optimized_config.json(indent=2))
        modify = typer.prompt("Do you want to modify this configuration? (Y/n)", default="n")
        if modify.lower() == 'y':
            # Placeholder for modification logic
            typer.echo("Modifying configurations... (This part is yet to be implemented)")

    # Confirm and save the configuration
    if not filename:
        filename = typer.prompt("Enter a filename to save your configuration (default: optimized_pipeline.yaml): ",
                                default="optimized_pipeline.yaml")
    save_configuration(optimized_config, filename)
    typer.echo(f"Configuration saved to {filename}. Your optimized pipeline is ready!")


if __name__ == "__main__":
    app()

==> dspygen-2024.10.15.tar.gz: dspygen-2024.10.15/src/dspygen/experiments/done/wizard.py <==
import typer
from typing import Optional
from pydantic import BaseModel, ValidationError
import yaml
import os
import json

from dspygen.llm_pipe.dsl_pydantic_models import PipelineConfigModel

app = typer.Typer()


def load_user_history() -> dict:
    """
    Simulate loading user's history to predict configurations.
    """
    # Placeholder for loading and analyzing user's history
    return {}


def generate_optimized_configuration(user_history: dict) -> PipelineConfigModel:
    """
    Generate an optimized pipeline configuration based on the user's history.
    """
    # Placeholder for AI logic to generate optimized configs
    return PipelineConfigModel()


def save_configuration(config: PipelineConfigModel, filename: str):
    """
    Save the generated pipeline configuration to a YAML file.
    """
    with open(filename, 'w') as file:
        yaml.dump(json.loads(config.json()), file)


@app.command()
def create_pipeline(filename: Optional[str] = typer.Option(None, "--filename", "-f",
                                                           help="Filename to save the pipeline configuration.")):
    """
    Main command to initiate the pipeline configuration generation process.
    """
    user_history = load_user_history()
    optimized_config = generate_optimized_configuration(user_history)

    # Proactively offer the optimized configuration with an option for details or modifications
    typer.echo("Based on your history, an optimized pipeline configuration has been generated.")
    action = typer.prompt("Do you want to proceed with the optimized configuration? (Y/n/details)", default="Y")

    if action.lower() == 'n':
        typer.echo("Exiting... You can start over and customize your configuration.")
        raise typer.Exit()
    elif action.lower() == 'details':
        typer.echo(optimized_config.json(indent=2))
        modify = typer.prompt("Do you want to modify this configuration? (Y/n)", default="n")
        if modify.lower() == 'y':
            # Placeholder for modification logic
            typer.echo("Modifying configurations... (This part is yet to be implemented)")

    # Confirm and save the configuration
    if not filename:
        filename = typer.prompt("Enter a filename to save your configuration (default: optimized_pipeline.yaml): ",
                                default="optimized_pipeline.yaml")
    save_configuration(optimized_config, filename)
    typer.echo(f"Configuration saved to {filename}. Your optimized pipeline is ready!")


if __name__ == "__main__":
    app()
